@@ -84,12 +84,13 @@ var _ = ginkgo.Describe("the ntfy service", func() {
 					Firebase:               true,
 					Cache:                  true,
 					DisableTLSVerification: false,
+					DisableTLS:             false,
 				}))
 			})
 		})
 		ginkgo.When("parsing the configuration URL", func() {
 			ginkgo.It("should be identical after de-/serialization", func() {
-				testURL := "ntfy://user:pass@example.com:2225/topic?cache=No&click=CLICK&disabletls=No&firebase=No&icon=ICON&priority=Max&scheme=http&title=TITLE"
+				testURL := "ntfy://user:pass@example.com:2225/topic?cache=No&click=CLICK&disabletls=No&disabletlsverification=No&firebase=No&icon=ICON&priority=Max&scheme=http&title=TITLE"
 				config := &Config{}
 				service.client = jsonclient.NewWithHTTPClient(service.httpClient)
 				pkr := format.NewPropKeyResolver(config)
@@ -149,7 +150,7 @@ var _ = ginkgo.Describe("the ntfy service", func() {
 				testutils.TestConfigSetInvalidQueryValue(&Config{}, "ntfy://host/topic?foo=bar")
 				testutils.TestConfigSetDefaultValues(&Config{})
 				testutils.TestConfigGetEnumsCount(&Config{}, 1)
-				testutils.TestConfigGetFieldsCount(&Config{}, 16)
+				testutils.TestConfigGetFieldsCount(&Config{}, 17)
 			})
 		})
 		ginkgo.Describe("the service instance", func() {
@@ -203,7 +204,7 @@ var _ = ginkgo.Describe("the ntfy service", func() {
 				server := httptest.NewUnstartedServer(
 					http.HandlerFunc(func(w http.ResponseWriter, _ *http.Request) {
 						w.WriteHeader(http.StatusOK)
-						_, _ = w.Write([]byte("OK")) // nolint:errcheck // test handler
+						_, _ = w.Write([]byte("OK"))
 					}),
 				)
 				server.TLS = &tls.Config{
@@ -244,7 +245,7 @@ var _ = ginkgo.Describe("the ntfy service", func() {
 			server := httptest.NewTLSServer(
 				http.HandlerFunc(func(w http.ResponseWriter, _ *http.Request) {
 					w.WriteHeader(http.StatusOK)
-					_, _ = w.Write([]byte("OK")) // nolint:errcheck // test handler
+					_, _ = w.Write([]byte("OK"))
 				}),
 			)
 			defer server.Close()
@@ -267,7 +268,7 @@ var _ = ginkgo.Describe("the ntfy service", func() {
 			gomega.Expect(err).To(gomega.Not(gomega.HaveOccurred()))
 			gomega.Expect(resp.StatusCode).To(gomega.Equal(http.StatusOK))
 
-			_ = resp.Body.Close() // nolint:errcheck // test cleanup
+			_ = resp.Body.Close()
 		})
 
 		ginkgo.It(
@@ -309,7 +310,7 @@ var _ = ginkgo.Describe("the ntfy service", func() {
 						}
 						w.Header().Set("Content-Type", "application/json")
 						w.WriteHeader(http.StatusOK)
-						_ = json.NewEncoder(w).Encode(response) // nolint:errcheck // test handler
+						_ = json.NewEncoder(w).Encode(response)
 					}),
 				)
 				server.TLS = &tls.Config{
@@ -383,7 +384,7 @@ var _ = ginkgo.Describe("the ntfy service", func() {
 						}
 						w.Header().Set("Content-Type", "application/json")
 						w.WriteHeader(http.StatusOK)
-						_ = json.NewEncoder(w).Encode(response) // nolint:errcheck // test handler
+						_ = json.NewEncoder(w).Encode(response)
 					}),
 				)
 				server.TLS = &tls.Config{
@@ -509,7 +510,7 @@ var _ = ginkgo.Describe("the ntfy service", func() {
 					}
 					w.Header().Set("Content-Type", "application/json")
 					w.WriteHeader(http.StatusOK)
-					_ = json.NewEncoder(w).Encode(response) // nolint:errcheck // test handler
+					_ = json.NewEncoder(w).Encode(response)
 				}),
 			)
 			server.TLS = &tls.Config{
@@ -648,7 +649,7 @@ var _ = ginkgo.Describe("the ntfy service", func() {
 					}
 					w.Header().Set("Content-Type", "application/json")
 					w.WriteHeader(http.StatusOK)
-					_ = json.NewEncoder(w).Encode(response) // nolint:errcheck // test handler
+					_ = json.NewEncoder(w).Encode(response)
 				}),
 			)
 			server.TLS = &tls.Config{
@@ -741,7 +742,7 @@ var _ = ginkgo.Describe("the ntfy service", func() {
 					}
 					w.Header().Set("Content-Type", "application/json")
 					w.WriteHeader(http.StatusOK)
-					_ = json.NewEncoder(w).Encode(response) // nolint:errcheck // test handler
+					_ = json.NewEncoder(w).Encode(response)
 				}),
 			)
 			server.TLS = &tls.Config{
@@ -867,7 +868,7 @@ var _ = ginkgo.Describe("the ntfy service", func() {
 						}
 						w.Header().Set("Content-Type", "application/json")
 						w.WriteHeader(http.StatusOK)
-						_ = json.NewEncoder(w).Encode(response) // nolint:errcheck // test handler
+						_ = json.NewEncoder(w).Encode(response)
 					}),
 				)
 				server.TLS = &tls.Config{
@@ -946,7 +947,7 @@ var _ = ginkgo.Describe("the ntfy service", func() {
 						}
 						w.Header().Set("Content-Type", "application/json")
 						w.WriteHeader(http.StatusOK)
-						_ = json.NewEncoder(w).Encode(response) // nolint:errcheck // test handler
+						_ = json.NewEncoder(w).Encode(response)
 					}),
 				)
 				defer server.Close()
@@ -1018,7 +1019,7 @@ var _ = ginkgo.Describe("the ntfy service", func() {
 						}
 						w.Header().Set("Content-Type", "application/json")
 						w.WriteHeader(http.StatusOK)
-						_ = json.NewEncoder(w).Encode(response) // nolint:errcheck // test handler
+						_ = json.NewEncoder(w).Encode(response)
 					}),
 				)
 				server.TLS = &tls.Config{
@@ -1104,7 +1105,7 @@ var _ = ginkgo.Describe("the ntfy service", func() {
 						}
 						w.Header().Set("Content-Type", "application/json")
 						w.WriteHeader(http.StatusOK)
-						_ = json.NewEncoder(w).Encode(response) // nolint:errcheck // test handler
+						_ = json.NewEncoder(w).Encode(response)
 					}),
 				)
 				server.TLS = &tls.Config{
@@ -1278,7 +1279,7 @@ var _ = ginkgo.Describe("the ntfy service", func() {
 						}
 						w.Header().Set("Content-Type", "application/json")
 						w.WriteHeader(http.StatusOK)
-						_ = json.NewEncoder(w).Encode(response) // nolint:errcheck // test handler
+						_ = json.NewEncoder(w).Encode(response)
 					}),
 				)
 				server.TLS = &tls.Config{
@@ -1431,60 +1432,62 @@ var _ = ginkgo.Describe("the ntfy service", func() {
 		})
 	})
 
-	ginkgo.Describe("DisableTLS configuration", func() {
-		ginkgo.It(
-			"should use HTTPS scheme and set InsecureSkipVerify when DisableTLS is true",
-			func() {
+	ginkgo.Describe("TLS configuration", func() {
+		ginkgo.Describe("DisableTLSVerification", func() {
+			ginkgo.It(
+				"should set InsecureSkipVerify when DisableTLSVerification is true",
+				func() {
+					serviceURL := testutils.URLMust(
+						"ntfy://example.com/test?disabletlsverification=yes",
+					)
+					gomega.Expect(service.Initialize(serviceURL, logger)).To(gomega.Succeed())
+
+					transport := service.httpClient.Transport.(*http.Transport)
+					gomega.Expect(transport.TLSClientConfig.InsecureSkipVerify).To(gomega.BeTrue())
+				},
+			)
+
+			ginkgo.It("should log warning when DisableTLSVerification is enabled", func() {
+				// This test verifies that a warning is logged when TLS verification is disabled
+				serviceURL := testutils.URLMust(
+					"ntfy://example.com/test?disabletlsverification=yes",
+				)
+				gomega.Expect(service.Initialize(serviceURL, logger)).To(gomega.Succeed())
+				gomega.Expect(service.Config.DisableTLSVerification).To(gomega.BeTrue())
+			})
+
+			ginkgo.It(
+				"should not set InsecureSkipVerify when DisableTLSVerification is false",
+				func() {
+					serviceURL := testutils.URLMust("ntfy://example.com/test")
+					gomega.Expect(service.Initialize(serviceURL, logger)).To(gomega.Succeed())
+
+					// Check that the HTTP client does not have InsecureSkipVerify set
+					transport := service.httpClient.Transport.(*http.Transport)
+					gomega.Expect(transport.TLSClientConfig == nil || transport.TLSClientConfig.InsecureSkipVerify == false).
+						To(gomega.BeTrue())
+				},
+			)
+		})
+
+		ginkgo.Describe("DisableTLS", func() {
+			ginkgo.It("should use HTTP scheme when DisableTLS is true", func() {
 				serviceURL := testutils.URLMust("ntfy://example.com/test?disabletls=yes")
 				gomega.Expect(service.Initialize(serviceURL, logger)).To(gomega.Succeed())
 
 				gomega.Expect(service.Config.GetAPIURL()).
-					To(gomega.Equal("https://example.com/test"))
+					To(gomega.Equal("http://example.com/test"))
+			})
 
-				transport := service.httpClient.Transport.(*http.Transport)
-				gomega.Expect(transport.TLSClientConfig.InsecureSkipVerify).To(gomega.BeTrue())
-			},
-		)
-
-		ginkgo.It("should use HTTPS scheme when DisableTLS is false", func() {
-			config := &Config{
-				Host:                   "example.com",
-				Topic:                  "test",
-				Scheme:                 "https",
-				DisableTLSVerification: false,
-			}
-			gomega.Expect(config.GetAPIURL()).To(gomega.Equal("https://example.com/test"))
-		})
-
-		ginkgo.It(
-			"should configure HTTP client with InsecureSkipVerify when DisableTLS is true",
-			func() {
-				serviceURL := testutils.URLMust("ntfy://example.com/test?disabletls=yes")
-				gomega.Expect(service.Initialize(serviceURL, logger)).To(gomega.Succeed())
-
-				// Check that the HTTP client has InsecureSkipVerify set
-				transport := service.httpClient.Transport.(*http.Transport)
-				gomega.Expect(transport.TLSClientConfig.InsecureSkipVerify).To(gomega.BeTrue())
-			},
-		)
-
-		ginkgo.It("should log warning when DisableTLS is enabled", func() {
-			// This test verifies that a warning is logged when TLS is disabled
-			// We can't easily test the log output directly, but we can verify the config is set
-			serviceURL := testutils.URLMust("ntfy://example.com/test?disabletls=yes")
-			gomega.Expect(service.Initialize(serviceURL, logger)).To(gomega.Succeed())
-			gomega.Expect(service.Config.DisableTLSVerification).To(gomega.BeTrue())
-		})
-
-		ginkgo.It("should not set InsecureSkipVerify when DisableTLS is false", func() {
-			serviceURL := testutils.URLMust("ntfy://example.com/test")
-			gomega.Expect(service.Initialize(serviceURL, logger)).To(gomega.Succeed())
-
-			// Check that the HTTP client does not have InsecureSkipVerify set
-			// If TLSClientConfig is nil, it means InsecureSkipVerify is not set (equivalent to false)
-			transport := service.httpClient.Transport.(*http.Transport)
-			gomega.Expect(transport.TLSClientConfig == nil || transport.TLSClientConfig.InsecureSkipVerify == false).
-				To(gomega.BeTrue())
+			ginkgo.It("should use HTTPS scheme when DisableTLS is false", func() {
+				config := &Config{
+					Host:       "example.com",
+					Topic:      "test",
+					Scheme:     "https",
+					DisableTLS: false,
+				}
+				gomega.Expect(config.GetAPIURL()).To(gomega.Equal("https://example.com/test"))
+			})
 		})
 	})
 })
